@@ -1,8 +1,8 @@
-from typing import Any, Callable, NamedTuple
+from typing import Any, Callable, NamedTuple, Optional, Union
 
 from graphql_relay.utils.base64 import base64, unbase64
 
-from graphql.type import (
+from graphql import (
     GraphQLArgument,
     GraphQLNonNull,
     GraphQLID,
@@ -22,8 +22,8 @@ class GraphQLNodeDefinitions(NamedTuple):
 
 
 def node_definitions(
-    id_fetcher: Callable[[str, GraphQLResolveInfo], Any],
-    type_resolver: GraphQLTypeResolver = None,
+    fetch_by_id: Callable[[str, GraphQLResolveInfo], Any],
+    type_resolver: Optional[GraphQLTypeResolver] = None,
 ) -> GraphQLNodeDefinitions:
     """
     Given a function to map from an ID to an underlying object, and a function
@@ -55,18 +55,19 @@ def node_definitions(
                 GraphQLNonNull(GraphQLID), description="The ID of an object"
             )
         },
-        resolve=lambda _obj, info, id: id_fetcher(id, info),
+        resolve=lambda _obj, info, id: fetch_by_id(id, info),
     )
 
     nodes_field = GraphQLField(
         GraphQLNonNull(GraphQLList(node_interface)),
+        description="Fetches objects given their IDs",
         args={
             "ids": GraphQLArgument(
                 GraphQLNonNull(GraphQLList(GraphQLNonNull(GraphQLID))),
                 description="The IDs of objects",
             )
         },
-        resolve=lambda _obj, info, ids: [id_fetcher(id_, info) for id_ in ids],
+        resolve=lambda _obj, info, ids: [fetch_by_id(id_, info) for id_ in ids],
     )
 
     return GraphQLNodeDefinitions(node_interface, node_field, nodes_field)
@@ -78,12 +79,12 @@ class ResolvedGlobalId(NamedTuple):
     id: str
 
 
-def to_global_id(type_: str, id_: str) -> str:
+def to_global_id(type_: str, id_: Union[str, int]) -> str:
     """
     Takes a type name and an ID specific to that type name, and returns a
     "global ID" that is unique among all types.
     """
-    return base64(f"{type_}:{id_}")
+    return base64(f"{type_}:{GraphQLID.serialize(id_)}")
 
 
 def from_global_id(global_id: str) -> ResolvedGlobalId:
@@ -91,11 +92,15 @@ def from_global_id(global_id: str) -> ResolvedGlobalId:
     Takes the "global ID" created by to_global_id, and returns the type name and ID
     used to create it.
     """
-    return ResolvedGlobalId(*unbase64(global_id).split(":", 1))
+    global_id = unbase64(global_id)
+    if ":" not in global_id:
+        return ResolvedGlobalId("", global_id)
+    return ResolvedGlobalId(*global_id.split(":", 1))
 
 
 def global_id_field(
-    type_name: str = None, id_fetcher: Callable[[Any, GraphQLResolveInfo], str] = None
+    type_name: Optional[str] = None,
+    id_fetcher: Optional[Callable[[Any, GraphQLResolveInfo], str]] = None,
 ) -> GraphQLField:
     """
     Creates the configuration for an id field on a node, using `to_global_id` to
